Description Usage Arguments Value Examples
Compute optimal transport between X and Y and create allocation and transport images
1 2 3 4 5 6 7 | extract.otf.image.3d(
from.image,
to.image,
mass.cost = 0,
transport.type = 3,
p.degree = 2
)
|
from.image |
3d array |
to.image |
3d array |
mass.cost |
cost of allocating or removing mass |
transport.type |
optimal transport mode default=3: \n 0 - Balanced (equalizes source and target mass) 1 - Add mass (Only allow addition of mass in soutrce or target) 2 - Subtract mass (Only allow subtraction of mass in source or target) 3 - Match source mass (Add or subtract in source to match target) 4 - Free (Add or subtract mass anywhere) 5 - Free source only (Add or subtract mass in source only) |
p.degere |
optimal transport cost degree (i.e. cost^p.degreee) |
list with allocation and trasnport cost images in from and to
1 2 3 4 5 6 7 8 9 10 11 |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.