Description Usage Arguments Value
Compute optimal transport between X and Y and create allocation and transport images
1 2 3 4 5 6 7 8 9 | extract.otf.points(
from,
to,
from.weight = 1,
to.weight = 1,
mass.cost = 0,
transport.type = 3,
p.degree = 2
)
|
from |
3d array |
to |
3d array |
mass.cost |
cost of allocating or removing mass |
transport.type |
optimal transport mode default=3: \n 0 - Balanced (equalizes source and target mass) 1 - Add mass (Only allow addition of mass in soutrce or target) 2 - Subtract mass (Only allow subtraction of mass in source or target) 3 - Match source mass (Add or subtract in source to match target) 4 - Free (Add or subtract mass anywhere) 5 - Free source only (Add or subtract mass in source only) |
from.weights |
weights of from points |
to.weights |
weights of to points |
p.degere |
optimal transport cost degree (i.e. cost^p.degreee) |
list woth allocation and trasnport cost images in from and to
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.